@@ -517,8 +517,8 @@ OC.L10N.register(
     "Failed" : "C'hwitet",
     "OK" : "OK",
     "Confirm" : "Kadarnañ",
-    "Back" : "Distro",
     "Cancel" : "Nullañ",
+    "Back" : "Distro",
     "Calendar" : "Deiziataer",
     "Save" : "Enrollañ",
     "Search participants" : "Klask implijer",
@@ -554,9 +554,9 @@ OC.L10N.register(
     "Choose" : "Dibab",
     "Conversation settings" : "Stummoù diviz",
     "Personal" : "Personel",
-    "Do you really want to delete \"{displayName}\"?" : "Sur oc'h da zilemel  \"{displayName}\"?",
     "Leave conversation" : "Kuitaat an diviz",
     "Delete conversation" : "Dilemel an diviz",
+    "Do you really want to delete \"{displayName}\"?" : "Sur oc'h da zilemel  \"{displayName}\"?",
     "Password protection" : "Gwareziñ gant ur ger-tremen",
     "Start time (optional)" : "Amzer kregiñ (dibab)",
     "Edit" : "Cheñch",
@@ -631,8 +631,9 @@ OC.L10N.register(
     "Select conversation" : "Choaz un diviz",
     "Select location for attachments" : "Choazit ul lec'h evit stagañ",
     "Error while setting attachment folder" : "Ur fazi a zo bet en ur lakaat an teuliad stagañ",
-    "Attachments folder" : "Teuliad stag",
+    "Notification settings" : "Arventennoù kemennadennoù",
     "Privacy" : "Prevezder",
+    "Attachments folder" : "Teuliad stag",
     "Search" : "Klask",
     "Start call" : "Kregiñ ar gemenadenn",
     "You will be able to join the call only after a moderator starts it." : "Posupl vo deoc'h mont er gemenadenn goude ma vo bet groget gant ar modertator.",
@@ -712,20 +713,12 @@ OC.L10N.register(
     "You were invited to a conversation." : "Kouviet oc'h en un diviz",
     "Click the button below to join." : "Klikit war ar bouton evit mont",
     "Join »%s«" : "Mont da »%s«",
-    "{user} invited you to a private conversation" : "{user} en deus kouviet ac'hanoc'h en un diviz prevez",
-    "Copy conversation link" : "Eilañ al liamm diviz",
     "Today" : "Hiziv",
     "Yesterday" : "Dec'h",
     "_%n day ago_::_%n days ago_" : ["%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo"],
-    "Close" : "Serriñ",
     "Choose devices" : "Choazit un ardivink",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Adnevesaet e bet Nextcloud Talk, ret eo deoc'h freskaat ar bajenn a raok kregiñ pe mont en ut gamanadenn.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Rannañ  ho skramm a dro nmetken gant  Firefox stumm 52 pe nevezoc'h.",
     "Screensharing extension is required to share your screen." : "Un astenn rannañ-skramm ez eus ezhomm evit rannañ ho srkamm.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm.",
-    "Nextcloud Talk was updated, please reload the page" : "Adnevesaet eo bet Nextcloud Talk , adkargit ar bajenn",
-    "Failed to join the conversation. Try to reload the page." : "C'hwitet da mont en diviz. Klaksit adkargañ ar bajenn.",
-    "Nextcloud is in maintenance mode, please reload the page" : "E stumm dalc'h eo Nextcloud, adkargit ar bajenn",
-    "Lost connection to signaling server. Try to reload the page manually." : "Kenstagadenn gant ar servijour arhent kollet. Klaskit adkemprenn gant an dorn."
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm."
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
