@@ -63,6 +63,7 @@ OC.L10N.register(
     "{actor} deleted a message" : "הודעה נמחקה על ידי {actor}",
     "You deleted a message" : "מחקת הודעה",
     "Message deleted by author" : "ההודעה נמחקה על ידי מי שפרסם אותה",
+    "Deleted user" : "משתמש מחוק",
     "Administration" : "ניהול",
     "System" : "מערכת",
     "Talk conversations" : "דיוני שיח",
@@ -401,8 +402,8 @@ OC.L10N.register(
     "Checking …" : "מתבצעת בדיקה…",
     "Confirm" : "אימות",
     "Reset" : "איפוס",
-    "Back" : "חזרה",
     "Cancel" : "ביטול",
+    "Back" : "חזרה",
     "Loading …" : "בטעינה…",
     "From" : "מאת",
     "To" : "אל",
@@ -426,6 +427,7 @@ OC.L10N.register(
     "You" : "אני",
     "Show screen" : "הצגת מסך",
     "Collapse" : "קיווץ",
+    "Expand" : "הרחבה",
     "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
     "Favorite" : "סימון כמועדף",
     "Date:" : "בתאריך:",
@@ -462,9 +464,12 @@ OC.L10N.register(
     "Mark as unread" : "סימון כלא נקרא",
     "Remove from favorites" : "הסרה מהמועדפים",
     "Add to favorites" : "הוספה למועדפים",
+    "Home" : "בית",
+    "Unread" : "לא נקרא",
     "No matches found" : "לא נמצאו התאמות",
     "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
     "Unread messages" : "הודעות שלא נקראו",
+    "Threads" : "שרשורים",
     "Clear filter" : "מחיקת מסנן",
     "Users" : "משתמשים",
     "Groups" : "קבוצות",
@@ -479,6 +484,7 @@ OC.L10N.register(
     "Upload" : "העלאה",
     "Files" : "קבצים",
     "Reply" : "תגובה",
+    "More actions" : "פעולות נוספות",
     "Go to file" : "מעבר לקובץ",
     "Translate" : "תרגום",
     "Dismiss" : "התעלמות",
@@ -521,14 +527,11 @@ OC.L10N.register(
     "Link to a conversation" : "קישור לדיון",
     "Select conversation" : "בחירת דיון",
     "Select location for attachments" : "בחירת מיקום לקבצים מצורפים",
-    "Attachments folder" : "תיקיית הקבצים המצורפים",
-    "Appearance" : "מראה",
+    "Notification settings" : "הגדרות התראה",
     "Privacy" : "פרטיות",
-    "Performance" : "ביצועים",
-    "Keyboard shortcuts" : "קיצורי מקלדת",
+    "Attachments folder" : "תיקיית הקבצים המצורפים",
     "Search" : "חיפוש",
     "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
-    "More actions" : "פעולות נוספות",
     "Start call" : "התחלת שיחה",
     "Screensharing options" : "אפשרויות שיתוף מסך",
     "Enable screensharing" : "הפעלת שיתוף מסך",
@@ -608,6 +611,9 @@ OC.L10N.register(
     "Yesterday" : "מחר",
     "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים","לפני %n ימים","לפני %n ימים"],
     "Choose devices" : "בחירת התקנים",
+    "Appearance" : "מראה",
+    "Performance" : "ביצועים",
+    "Keyboard shortcuts" : "קיצורי מקלדת",
     "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
     "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך."
