@@ -266,8 +266,8 @@ OC.L10N.register(
     "Federated user" : "Utilizador federado",
     "Confirm" : "Confirmar",
     "Reset" : "Reiniciar",
-    "Back" : "Anterior",
     "Cancel" : "Cancelar",
+    "Back" : "Anterior",
     "Now" : "Agora",
     "From" : "De",
     "To" : "Para",
@@ -301,6 +301,7 @@ OC.L10N.register(
     "Delete conversation" : "Eliminar conversação",
     "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
     "_%n day_::_%n days_" : ["%n dia","%n dias","%n dias"],
+    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "As mensagens de chat podem expirar após um determinado período. Nota: os ficheiros partilhados no chat não serão eliminados para o proprietário, mas deixarão de ser partilhados na conversa.",
     "Password protection" : "Protegido por palavra-passe",
     "Set a password" : "Definir uma palavra-passe",
     "Edit" : "Editar",
@@ -314,7 +315,6 @@ OC.L10N.register(
     "Add to favorites" : "Adicionar aos favoritos",
     "Home" : "Início",
     "Clear filter" : "Limpar filtro",
-    "Talk settings" : "Definições do Falar",
     "Users" : "Utilizadores",
     "Groups" : "Grupos",
     "Teams" : "Grupos",
@@ -326,6 +326,7 @@ OC.L10N.register(
     "Message forwarded to \"Note to self\"" : "Mensagem reencaminhada para \"Nota a mim\"",
     "Error while forwarding message to \"Note to self\"" : "Erro ao reencaminhar mensagem para \"Nota a mim\"",
     "Reply" : "Resposta",
+    "More actions" : "Mais ações",
     "Download file" : "Transferir ficheiro",
     "Translate" : "Traduzir",
     "Dismiss" : "Dispensar",
@@ -333,6 +334,7 @@ OC.L10N.register(
     "No messages" : "Sem mensagens",
     "Create a new group conversation" : "Criar nova conversa de grupo",
     "Send message" : "Enviar mensagem",
+    "File to share" : "Ficheiro a partilhar",
     "New file" : "Ficheiro novo",
     "Send" : "Enviar",
     "Settings" : "Definições",
@@ -343,6 +345,7 @@ OC.L10N.register(
     "Promote to moderator" : "Promover a moderador",
     "Remove" : "Remover",
     "Add users or groups" : "Add users or groups",
+    "Add users" : "Adicionar utilizadores",
     "Integrations" : "Integrações",
     "Searching …" : "À procura …",
     "Participants" : "Participantes",
@@ -353,11 +356,10 @@ OC.L10N.register(
     "Load more results" : "Mostrar mais resultados",
     "Projects" : "Projectos",
     "No shared items" : "Sem itens partilhados",
+    "Appearance & Sounds" : "Aspeto e sons",
+    "Notification settings" : "Definições de notificação",
     "Privacy" : "Privacidade",
-    "Performance" : "Performance",
-    "Keyboard shortcuts" : "Atalhos de teclado",
     "Search" : "Pesquisa sobre",
-    "More actions" : "Mais ações",
     "Screensharing options" : "Opções de partilha de ecrã",
     "Enable screensharing" : "Ativar partilha de ecrã",
     "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
@@ -395,10 +397,13 @@ OC.L10N.register(
     "Tasks" : "Tarefas",
     "Notes" : "Notas",
     "Reports" : "Relatórios",
+    "Talk settings" : "Definições do Falar",
     "Today" : "Hoje",
     "Yesterday" : "Ontem",
     "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás","%n dias atrás"],
-    "Close" : "Fechar",
+    "Appearance" : "Aspeto",
+    "Performance" : "Performance",
+    "Keyboard shortcuts" : "Atalhos de teclado",
     "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
     "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor use um browser diferente como o Firefox ou o Chrome para partilhar o seu ecrã."
