@@ -19,7 +19,9 @@ use OCA\Talk\Manager as RoomManager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
+use OCA\Talk\Service\ThreadService;
 use OCA\Talk\Webinary;
+use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
 use OCP\IL10N;
@@ -50,12 +52,14 @@ class MessageSearch implements IProvider, IFilteringProvider {
 		protected IL10N $l,
 		protected Config $talkConfig,
 		protected IUserSession $userSession,
+		protected ThreadService $threadService,
 	) {
 	}
 
 	/**
 	 * @inheritDoc
 	 */
+	#[\Override]
 	public function getId(): string {
 		return 'talk-message';
 	}
@@ -63,6 +67,7 @@ class MessageSearch implements IProvider, IFilteringProvider {
 	/**
 	 * @inheritDoc
 	 */
+	#[\Override]
 	public function getName(): string {
 		return $this->l->t('Messages');
 	}
@@ -70,6 +75,7 @@ class MessageSearch implements IProvider, IFilteringProvider {
 	/**
 	 * @inheritDoc
 	 */
+	#[\Override]
 	public function getOrder(string $route, array $routeParameters): ?int {
 		$currentUser = $this->userSession->getUser();
 		if ($currentUser && $this->talkConfig->isDisabledForUser($currentUser)) {
@@ -101,6 +107,7 @@ class MessageSearch implements IProvider, IFilteringProvider {
 	/**
 	 * @inheritDoc
 	 */
+	#[\Override]
 	public function search(IUser $user, ISearchQuery $query): SearchResult {
 		$title = $this->l->t('Messages');
 		$currentToken = $this->getCurrentConversationToken($query);
@@ -137,13 +144,13 @@ class MessageSearch implements IProvider, IFilteringProvider {
 	public function performSearch(IUser $user, ISearchQuery $query, string $title, array $rooms, bool $isCurrentMessageSearch = false): SearchResult {
 		$roomMap = [];
 		foreach ($rooms as $room) {
-			if (!$isCurrentMessageSearch &&
-				$room->getType() === Room::TYPE_CHANGELOG) {
+			if (!$isCurrentMessageSearch
+				&& $room->getType() === Room::TYPE_CHANGELOG) {
 				continue;
 			}
 
-			if (!$isCurrentMessageSearch &&
-				$this->getCurrentConversationToken($query) === $room->getToken()) {
+			if (!$isCurrentMessageSearch
+				&& $this->getCurrentConversationToken($query) === $room->getToken()) {
 				// No search result from current conversation
 				continue;
 			}
@@ -191,7 +198,7 @@ class MessageSearch implements IProvider, IFilteringProvider {
 		$comments = $this->chatManager->searchForObjectsWithFilters(
 			$query->getTerm(),
 			array_keys($roomMap),
-			ChatManager::VERB_MESSAGE,
+			[ChatManager::VERB_MESSAGE, ChatManager::VERB_OBJECT_SHARED],
 			$lowerTimeBoundary,
 			$upperTimeBoundary,
 			$actorType,
@@ -278,6 +285,18 @@ class MessageSearch implements IProvider, IFilteringProvider {
 			}
 		}
 
+		$urlParams = [
+			'token' => $room->getToken(),
+			'_fragment' => 'message_' . $id,
+		];
+		$threadId = (int)$comment->getTopmostParentId() ?: (int)$comment->getId();
+		try {
+			$thread = $this->threadService->findByThreadId($room->getId(), $threadId);
+			$urlParams['threadId'] = $thread->getId();
+		} catch (DoesNotExistException) {
+			$thread = null;
+		}
+
 		$entry = new SearchResultEntry(
 			$iconUrl,
 			str_replace(
@@ -286,13 +305,16 @@ class MessageSearch implements IProvider, IFilteringProvider {
 				$subline
 			),
 			$messageStr,
-			$this->url->linkToRouteAbsolute('spreed.Page.showCall', ['token' => $room->getToken()]) . '#message_' . $comment->getId(),
+			$this->url->linkToRouteAbsolute('spreed.Page.showCall', $urlParams),
 			'icon-talk', // $iconClass,
 			true
 		);
 
 		$entry->addAttribute('conversation', $room->getToken());
 		$entry->addAttribute('messageId', $comment->getId());
+		if ($thread !== null) {
+			$entry->addAttribute('threadId', (string)$thread->getId());
+		}
 		$entry->addAttribute('actorType', $comment->getActorType());
 		$entry->addAttribute('actorId', $comment->getActorId());
 		$entry->addAttribute('timestamp', '' . $comment->getCreationDateTime()->getTimestamp());
@@ -300,6 +322,7 @@ class MessageSearch implements IProvider, IFilteringProvider {
 		return $entry;
 	}
 
+	#[\Override]
 	public function getSupportedFilters(): array {
 		return [
 			IFilter::BUILTIN_TERM,
@@ -310,10 +333,12 @@ class MessageSearch implements IProvider, IFilteringProvider {
 		];
 	}
 
+	#[\Override]
 	public function getAlternateIds(): array {
 		return ['talk-message'];
 	}
 
+	#[\Override]
 	public function getCustomFilters(): array {
 		return [
 			new FilterDefinition(self::CONVERSATION_FILTER)
