@@ -16,7 +16,9 @@ use OCA\Talk\Model\ProxyCacheMessage;
 use OCA\Talk\Model\Reminder;
 use OCA\Talk\Model\ReminderMapper;
 use OCP\AppFramework\Db\DoesNotExistException;
+use OCP\Comments\IComment;
 use OCP\Notification\IManager;
+use Psr\Log\LoggerInterface;
 
 class ReminderService {
 	public function __construct(
@@ -25,9 +27,14 @@ class ReminderService {
 		protected ChatManager $chatManager,
 		protected ProxyCacheMessageService $pcmService,
 		protected Manager $manager,
+		protected LoggerInterface $logger,
 	) {
 	}
 
+	public function getUpcomingReminders(string $userId, int $limit): array {
+		return $this->reminderMapper->findForUser($userId, $limit);
+	}
+
 	public function setReminder(string $userId, string $token, int $messageId, int $timestamp): Reminder {
 		try {
 			$reminder = $this->reminderMapper->findForUserAndMessage($userId, $token, $messageId);
@@ -91,6 +98,7 @@ class ReminderService {
 		$messageIds = [];
 		foreach ($reminders as $reminder) {
 			if (!isset($rooms[$reminder->getToken()])) {
+				$this->logger->warning('Ignoring reminder for user ' . $reminder->getUserId() . ' as conversation ' . $reminder->getToken() . ' could not be found');
 				continue;
 			}
 
@@ -113,6 +121,10 @@ class ReminderService {
 		$messages = $this->chatManager->getMessagesById($messageIds);
 
 		foreach ($reminders as $reminder) {
+			if (!isset($rooms[$reminder->getToken()])) {
+				continue;
+			}
+
 			$room = $rooms[$reminder->getToken()];
 			if (!$room->isFederatedConversation()) {
 				$key = $reminder->getMessageId();
@@ -129,10 +141,18 @@ class ReminderService {
 			}
 
 			if (!isset($messageList[$key])) {
+				$this->logger->warning('Ignoring reminder for user ' . $reminder->getUserId() . ' as messages #' . $reminder->getMessageId() . ' could not be found for conversation ' . $reminder->getToken());
 				continue;
 			}
 			$message = $messageList[$key];
 
+			if ($message instanceof IComment
+				&& ($message->getObjectType() !== 'chat'
+					|| $room->getId() !== (int)$message->getObjectId())) {
+				$this->logger->warning('Ignoring reminder for user ' . $reminder->getUserId() . ' as messages #' . $reminder->getMessageId() . ' could not be found for conversation ' . $reminder->getToken());
+				continue;
+			}
+
 			$notification = $this->notificationManager->createNotification();
 			$notification->setApp(Application::APP_ID)
 				->setUser($reminder->getUserId())
