@@ -4,9 +4,11 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Type\Types;
 
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Native\ComplianceNode;
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Node;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\CombiningType;
-use OCA\Talk\Vendor\CuyZ\Valinor\Type\ObjectType;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\CompositeType;
+use OCA\Talk\Vendor\CuyZ\Valinor\Type\ObjectType;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
 
 use function array_values;
@@ -37,6 +39,14 @@ final class IntersectionType implements CombiningType
         return true;
     }
 
+    public function compiledAccept(ComplianceNode $node): ComplianceNode
+    {
+        return Node::logicalAnd(...array_map(
+            fn (ObjectType $type) => $type->compiledAccept($node),
+            $this->types,
+        ));
+    }
+
     public function matches(Type $other): bool
     {
         if ($other instanceof MixedType) {
@@ -90,6 +100,16 @@ final class IntersectionType implements CombiningType
         return $this->types;
     }
 
+    public function nativeType(): IntersectionType
+    {
+        return new self(
+            ...array_map(
+                static fn (ObjectType $type) => $type->nativeType(),
+                $this->types,
+            ),
+        );
+    }
+
     public function toString(): string
     {
         return $this->signature;
